@@ -1,6 +1,6 @@
 /*
  * Copyright 2013 Canonical Ltd.
- * Copyright 2021 Robert Tari
+ * Copyright 2021-2022 Robert Tari
  *
  * Authors:
  *   Charles Kerr <charles.kerr@canonical.com>
@@ -655,13 +655,14 @@ create_switch_section (IndicatorSessionService * self, int profile)
     {
       if (want_accel)
         {
+            gchar *str = NULL;
+
             if (ayatana_common_utils_is_mate())
             {
-                gchar * str = g_settings_get_string (p->keybinding_settings, "screensaver");
-                g_menu_item_set_attribute (item, "accel", "s", str);
-                g_free (str);
+                str = g_settings_get_string (p->keybinding_settings, "screensaver");
+
             }
-            else
+            else if (p->keybinding_settings)
             {
                 gchar **lAccels = g_settings_get_strv(p->keybinding_settings, "screensaver");
 
@@ -671,6 +672,12 @@ create_switch_section (IndicatorSessionService * self, int profile)
                     g_strfreev(lAccels);
                 }
             }
+
+            if (str != NULL)
+            {
+                g_menu_item_set_attribute (item, "accel", "s", str);
+                g_free (str);
+            }
         }
 
       g_menu_append_item (menu, item);
@@ -1265,6 +1272,7 @@ indicator_session_service_init (IndicatorSessionService * self)
   /* init our priv pointer */
   p = indicator_session_service_get_instance_private (self);
   p->indicator_settings = g_settings_new ("org.ayatana.indicator.session");
+  p->keybinding_settings = NULL;
   if (ayatana_common_utils_is_mate())
     {
         p->keybinding_settings = g_settings_new ("org.mate.SettingsDaemon.plugins.media-keys");
@@ -1283,10 +1291,7 @@ indicator_session_service_init (IndicatorSessionService * self)
     }
   else if (ayatana_common_utils_is_lomiri())
     {
-        p->keybinding_settings = g_settings_new ("org.gnome.settings-daemon.plugins.media-keys");
-
-        /* Only use unity8 schema if it's installed; this avoids a hard dependency
-        on unity8-schemas */
+        // Lomiri does not have a keybinding schema. However it has a usage mode schema.
         usage_mode_schema = g_settings_schema_source_lookup (g_settings_schema_source_get_default (),
                                                        usage_mode_schema_name, TRUE);
         if (usage_mode_schema)
@@ -1370,8 +1375,11 @@ indicator_session_service_init (IndicatorSessionService * self)
 
   /* watch for changes to the lock keybinding */
   gp = p->keybinding_settings;
-  g_signal_connect_swapped (gp, "changed::screensaver",
-                            G_CALLBACK(rebuild_switch_section_soon), self);
+  if (gp)
+  {
+      g_signal_connect_swapped (gp, "changed::screensaver",
+                                G_CALLBACK(rebuild_switch_section_soon), self);
+  }
 
   self->priv->own_id = g_bus_own_name (G_BUS_TYPE_SESSION,
                                        BUS_NAME,
